#!/bin/sh

# This script file is used to change the date format in the asset.dat file and
# move the asset.dat file from cimom/bin to directory/data directory.
# Prior to director 4.2 the format in which the date was stored in asset.dat
# file was of the form "yyymmdd" and this file was stored in the CIMOM/bin
# directory. From 4.2 the format has changed to "yyy-mm-dd 00:00:00" and the
# file stored in the director/data directory. 

. /etc/DirAgent/cimom
ASSET_FILE=asset.dat

# The five date values that needs to be changed
LEASE_START_DATE=LEASE.startdate
LEASE_END_DATE=LEASE.enddate
USER_LAST_INVENTORIED=USER.LastInventoried
USER_PURCHASE_DATE=USER.purchasedate
WARRANTY_END_DATE=WARRANTY.enddate

# New place for asset.dat file
NEW_ASSETDAT_DIR=${CIMOM_ROOTDIR}/../data

cd ${CIMOM_ROOTDIR}/bin

changeToNewdate ()
{
    olddate=$1
    year=$(echo ${olddate:0:4})
    month=$(echo ${olddate:4:2})
    day=$(echo ${olddate:6:2})
    newdate=$(echo $year"-"$month"-"$day" 00:00:00")
    newval=$(echo $2"="$newdate)
    echo $newval >> $NEW_ASSETDAT_DIR/$ASSET_FILE
}

if [ -f $ASSET_FILE ]; then
    cat $ASSET_FILE | while read line ; do
    attr=$(echo $line | cut -d'=' -f1)
    case "$attr" in
        $LEASE_START_DATE | $LEASE_END_DATE | $USER_LAST_INVENTORIED | $USER_PURCHASE_DATE | $WARRANTY_END_DATE )
            olddatevalue=$(echo $line | cut -d'=' -f2) 
            if [ $(echo $olddatevalue | grep '^[0-9[0-9]') ]; then
                changeToNewdate $olddatevalue $attr
            else
                echo $line >> $NEW_ASSETDAT_DIR/$ASSET_FILE
            fi ;;
        * ) echo $line >> $NEW_ASSETDAT_DIR/$ASSET_FILE ;;
    esac
    rm -f $ASSET_FILE
    done
fi

