#!/bin/sh
#
# This configuration script should be run at install time and subsequently deleted.
# This file creates the certificate and private key for the cimserver.
# It also sets up other cimserver settings.
#
# This is located in /opt/IBM/director/CIMOM
#


# Replace the director host name in certdetails with the hostname of this agent
HOST=`hostname`
sed "s/%DirectorAgentServerName%/$HOST/" certdetails.txt > certdetails.txt.2

# Replace the cimom root with the actual absolute path
# There is probably an easier way to do this, but this works for now
. /etc/DirAgent/cimom
echo CIMOM_HOME=$CIMOM_ROOTDIR > home.tmp 
sed 's/\//\\\\\//g' home.tmp > home.tmp.2
. home.tmp.2
sed "s/%CIMOM_HOME%/$CIMOM_HOME/g" cimserver_planned.conf > cimserver_planned.conf.2
mv -f cimserver_planned.conf.2 cimserver_planned.conf
rm -f home.tmp home.tmp.2 

# Create keystore and truststore directories if they do not exist
mkdir -p keystore
mkdir -p truststore
chmod 700 keystore
chmod 700 truststore
chmod 744 cimserver_planned.conf
chmod 600 certdetails.txt

cd $CIMOM_ROOTDIR/bin
echo "Creating SSL certificate and private key"

# Create the private key and certificate 
./openssl genrsa -out ../keystore/server.key 1024 >/dev/null 2>&1 
./openssl req -config openssl.cnf -new -key ../keystore/server.key -out ../keystore/server.csr < ../certdetails.txt.2 >/dev/null 2>&1 
./openssl x509 -in ../keystore/server.csr -out ../keystore/server.cert -req -signkey ../keystore/server.key -days 500 >/dev/null 2>&1


cd $CIMOM_ROOTDIR

# Delete the certificate signing request and the certificate details 
# ATTN: Remove certdetails.txt after we know certificates are being created properly
rm -f keystore/server.csr certdetails.txt.2

# Copy the wbem file to /etc/pam.d so that PAM basic authentication works
mv -f wbem /etc/pam.d

