#!/bin/sh

# Licensed Materials - Property of IBM
#
# OCO Source Materials
#
# 09N6996
#
# (C) Copyright IBM Corp. 2004 All Rights Reserved
#
# The source code for this program is not published or other-
# wise divested of its trade secrets, irrespective of what has
# been deposited with the U.S. Copyright Office.

# This script determines system machine type and enables MPA inband
# eventing if the system is not supported by agent instrumentation.

# Find out where IBM Director is installed
if [ -f /etc/DirAgent/diragent ]; then
   # sets DIRAGT_ROOTDIR env var
   . /etc/DirAgent/diragent
else
   echo "MPA support: Could not determine IBM Director install location."
   exit 1;
fi

# Vars
PRODDATA_DIR=$DIRAGT_ROOTDIR/proddata
PRODDEF_DIR=$PRODDATA_DIR/defaults
DATA_DIR=$DIRAGT_ROOTDIR/data
CIMOM_DIR=$DIRAGT_ROOTDIR/CIMOM
MT_FILE=mtsupp
MPA_FILE=mpaagent.properties

# Get the system machine type
machtype=`./getmt`

isSupported=`grep "$machtype" $PRODDATA_DIR/$MT_FILE`

if [ "$isSupported" ]; then
   # Set up for intrumentation
   # compile sensor provider mofs
   # cimmof only seems to work by using this cmd structure
   cd $CIMOM_DIR/mof
   echo "Compiling sensor mofs..."
   ../bin/cimmof  -w -nroot/ibmsd -R.. -I../mof SensorProviderSchema.mof
   ../bin/cimmof  -w -nroot/PG_InterOp -R.. -I../mof SensorProviderRegistration.mof
   
   if [ -f $PRODDEF_DIR/$MPA_FILE ]; then
      sed 's:DO_INBAND_EVENTING=TRUE:DO_INBAND_EVENTING=FALSE:g' $PRODDEF_DIR/$MPA_FILE > $PRODDEF_DIR/$MPA_FILE.1
      mv $PRODDEF_DIR/$MPA_FILE.1 $PRODDEF_DIR/$MPA_FILE
   else
      echo "MPA support: Cannot locate file: $PRODDEF_DIR/$MPA_FILE"
   fi
   # modify properties file in data dir, if exists
   if [ -f $DATA_DIR/$MPA_FILE ]; then
      sed 's:DO_INBAND_EVENTING=TRUE:DO_INBAND_EVENTING=FALSE:g' $DATA_DIR/$MPA_FILE > $DATA_DIR/$MPA_FILE.1
      mv $DATA_DIR/$MPA_FILE.1 $DATA_DIR/$MPA_FILE
   fi
else
   # Enable MPA support
   if [ -f $PRODDEF_DIR/$MPA_FILE ]; then
      sed 's:DO_INBAND_EVENTING=FALSE:DO_INBAND_EVENTING=TRUE:g' $PRODDEF_DIR/$MPA_FILE > $PRODDEF_DIR/$MPA_FILE.1
      mv $PRODDEF_DIR/$MPA_FILE.1 $PRODDEF_DIR/$MPA_FILE
   else
      echo "MPA support: Cannot locate file: $PRODDEF_DIR/$MPA_FILE"
   fi
   # modify properties file in data dir, if exists
   if [ -f $DATA_DIR/$MPA_FILE ]; then
      sed 's:DO_INBAND_EVENTING=FALSE:DO_INBAND_EVENTING=TRUE:g' $DATA_DIR/$MPA_FILE > $DATA_DIR/$MPA_FILE.1
      mv $DATA_DIR/$MPA_FILE.1 $DATA_DIR/$MPA_FILE
   fi
fi

